@@ -158,8 +158,8 @@ def get_classes(
     dataset_path = Path(dataset_path)
     release_path = get_release_path(dataset_path, release_name)
 
-    classes_file = f"classes_{annotation_type}.txt"
-    classes = [e.strip() for e in open(release_path / "lists" / classes_file)]
+    classes_path = release_path / f"lists/classes_{annotation_type}.txt"
+    classes = classes_path.read_text().splitlines()
     if remove_background and classes[0] == "__background__":
         classes = classes[1:]
     return classes
